@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: example.cpp,v 1.26.4.1 2005/11/30 11:28:34 strk Exp $
+ * $Id: example.cpp 1834 2006-09-07 09:33:47Z strk $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -28,13 +28,48 @@
  *
  **********************************************************************/
 
+#include <vector>
 #include <sstream>
 #include <iomanip>
-#include <geos.h>
+#include <geos/geom/PrecisionModel.h>
+#include <geos/geom/GeometryFactory.h>
+#include <geos/geom/Geometry.h>
+#include <geos/geom/Point.h>
+#include <geos/geom/LinearRing.h>
+#include <geos/geom/LineString.h>
+#include <geos/geom/Polygon.h>
+#include <geos/geom/GeometryCollection.h>
+#include <geos/geom/Coordinate.h>
+#include <geos/geom/CoordinateSequence.h>
+#include <geos/geom/CoordinateArraySequence.h>
+#include <geos/geom/IntersectionMatrix.h>
+#include <geos/io/WKBReader.h>
+#include <geos/io/WKBWriter.h>
+#include <geos/io/WKTWriter.h>
+#include <geos/util/GeometricShapeFactory.h>
+#include <geos/util/GEOSException.h>
+#include <geos/util/IllegalArgumentException.h>
 #include <geos/opLinemerge.h>
 #include <geos/opPolygonize.h>
 
+#ifndef M_PI
+#define M_PI       3.14159265358979323846
+#endif
+
+// Set to 0 to skip section
+#define GEOMETRIC_SHAPES 1
+#define RELATIONAL_OPERATORS 1
+#define COMBINATIONS 1
+#define UNARY_OPERATIONS 1
+#define LINEMERGE 1
+#define POLYGONIZE 1
+
+
+using namespace std;
 using namespace geos;
+using namespace geos::geom;
+using namespace geos::operation::polygonize;
+using namespace geos::operation::linemerge;
 
 
 // Prototypes
@@ -60,8 +95,8 @@ GeometryFactory *global_factory;
 void WKBtest(vector<Geometry*>*geoms)
 {
 	stringstream s(ios_base::binary|ios_base::in|ios_base::out);
-	WKBReader wkbReader(*global_factory);
-	WKBWriter wkbWriter;
+	io::WKBReader wkbReader(*global_factory);
+	io::WKBWriter wkbWriter;
 	Geometry *gout;
 
 #if DEBUG_STREAM_STATE
@@ -142,11 +177,11 @@ void WKBtest(vector<Geometry*>*geoms)
 		if ( failed ) cout<<"{"<<i<<"} (WKB) ";
 		else cout<<"["<<i<<"] (WKB) ";
 
-		WKBReader::printHEX(s, cout);
+		io::WKBReader::printHEX(s, cout);
 		cout<<endl;
 
 		if ( failed ) {
-			WKTWriter wkt;
+			io::WKTWriter wkt;
 			cout<<"  IN: "<<wkt.write(gin)<<endl;
 			cout<<" OUT: "<<wkt.write(gout)<<endl;
 		}
@@ -168,7 +203,7 @@ wkt_print_geoms(vector<Geometry *> *geoms)
 	WKBtest(geoms); // test WKB parser
 
 	// WKT-print given geometries
-	WKTWriter *wkt = new WKTWriter();
+	io::WKTWriter *wkt = new io::WKTWriter();
 	for (unsigned int i=0; i<geoms->size(); i++) {
 		const Geometry *g = (*geoms)[i];
 		string tmp=wkt->write(g);
@@ -194,7 +229,7 @@ LineString *
 create_ushaped_linestring(double xoffset, double yoffset, double side)
 {
 	// We will use a coordinate list to build the linestring
-	CoordinateSequence *cl = new DefaultCoordinateSequence();
+	CoordinateSequence *cl = new CoordinateArraySequence();
 
 	cl->add(Coordinate(xoffset, yoffset));
 	cl->add(Coordinate(xoffset, yoffset+side));
@@ -221,7 +256,7 @@ LinearRing *
 create_square_linearring(double xoffset, double yoffset, double side)
 {
 	// We will use a coordinate list to build the linearring
-	CoordinateSequence *cl = new DefaultCoordinateSequence();
+	CoordinateSequence *cl = new CoordinateArraySequence();
 
 	cl->add(Coordinate(xoffset, yoffset));
 	cl->add(Coordinate(xoffset, yoffset+side));
@@ -297,14 +332,14 @@ create_simple_collection(vector<Geometry *> *geoms)
 Polygon *
 create_circle(double centerX, double centerY, double radius)
 {
-	GeometricShapeFactory shapefactory(global_factory);
+	util::GeometricShapeFactory shapefactory(global_factory);
 	shapefactory.setCentre(Coordinate(centerX, centerY));
 	shapefactory.setSize(radius);
 	// same as:
 	//	shapefactory.setHeight(radius);
 	//	shapefactory.setWidth(radius);
 	return shapefactory.createCircle();
-};
+}
 
 //
 // This function uses GeometricShapeFactory to render
@@ -313,12 +348,12 @@ create_circle(double centerX, double centerY, double radius)
 Polygon *
 create_ellipse(double centerX, double centerY, double width, double height)
 {
-	GeometricShapeFactory shapefactory(global_factory);
+	util::GeometricShapeFactory shapefactory(global_factory);
 	shapefactory.setCentre(Coordinate(centerX, centerY));
 	shapefactory.setHeight(height);
 	shapefactory.setWidth(width);
 	return shapefactory.createCircle();
-};
+}
 
 //
 // This function uses GeometricShapeFactory to render
@@ -328,14 +363,14 @@ create_ellipse(double centerX, double centerY, double width, double height)
 Polygon *
 create_rectangle(double llX, double llY, double width, double height)
 {
-	GeometricShapeFactory shapefactory(global_factory);
+	util::GeometricShapeFactory shapefactory(global_factory);
 	shapefactory.setBase(Coordinate(llX, llY));
 	shapefactory.setHeight(height);
 	shapefactory.setWidth(width);
 	shapefactory.setNumPoints(4); // we don't need more then 4 points for a rectangle...
 	// can use setSize for a square
 	return shapefactory.createRectangle();
-};
+}
 
 //
 // This function uses GeometricShapeFactory to render
@@ -345,14 +380,14 @@ create_rectangle(double llX, double llY, double width, double height)
 LineString *
 create_arc(double llX, double llY, double width, double height, double startang, double endang)
 {
-	GeometricShapeFactory shapefactory(global_factory);
+	util::GeometricShapeFactory shapefactory(global_factory);
 	shapefactory.setBase(Coordinate(llX, llY));
 	shapefactory.setHeight(height);
 	shapefactory.setWidth(width);
 	// shapefactory.setNumPoints(100); // the default (100 pts)
 	// can use setSize for a square
 	return shapefactory.createArc(startang, endang);
-};
+}
 
 // Start reading here
 void do_all()
@@ -378,12 +413,14 @@ void do_all()
 
 	// Read function bodies to see the magic behind them
 	geoms->push_back(create_point(150, 350));
+	geoms->push_back(create_square_linearring(0,0,100));
 	geoms->push_back(create_ushaped_linestring(60,60,100));
 	geoms->push_back(create_square_linearring(0,0,100));
 	geoms->push_back(create_square_polygon(0,200,300));
 	geoms->push_back(create_square_polygon(0,250,300));
 	geoms->push_back(create_simple_collection(geoms));
 
+#if GEOMETRIC_SHAPES
 	// These ones use a GeometricShapeFactory
 	geoms->push_back(create_circle(0, 0, 10));
 	geoms->push_back(create_ellipse(0, 0, 8, 12));
@@ -391,12 +428,15 @@ void do_all()
 	geoms->push_back(create_rectangle(-5, -5, 10, 20)); // a rectangle
 	// The upper-right quarter of a vertical ellipse
 	geoms->push_back(create_arc(0, 0, 10, 20, 0, M_PI/2));
+#endif
 
 	// Print all geoms.
 	cout<<"--------HERE ARE THE BASE GEOMS ----------"<<endl;
 	wkt_print_geoms(geoms);
 
 
+#if UNARY_OPERATIONS
+
 ////////////////////////////////////////////////////////////////////////
 // UNARY OPERATIONS
 ////////////////////////////////////////////////////////////////////////
@@ -433,9 +473,8 @@ void do_all()
 			Geometry *g2 = g->buffer(10);
 			newgeoms->push_back(g2);
 		}
-		catch (GEOSException *exc) {
-			cerr <<"GEOS Exception: geometry "<<i<<"->buffer(10): "<<exc->toString()<<"\n";
-			delete exc;
+		catch (const util::GEOSException& exc) {
+			cerr <<"GEOS Exception: geometry "<<i<<"->buffer(10): "<<exc.what()<<"\n";
 		}
 	}
 
@@ -468,6 +507,10 @@ void do_all()
 	}
 	delete newgeoms;
 
+#endif // UNARY_OPERATIONS
+
+#if RELATIONAL_OPERATORS
+
 ////////////////////////////////////////////////////////////////////////
 // RELATIONAL OPERATORS
 ////////////////////////////////////////////////////////////////////////
@@ -496,13 +539,11 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (IllegalArgumentException *exc) {
+			catch (const util::IllegalArgumentException& exc) {
 				cout<<" X\t";
-				delete exc;
 			}
-			catch (GEOSException *exc) {
-				cerr<<exc->toString()<<endl;
-				delete exc;
+			catch (const std::exception& exc) {
+				cerr<<exc.what()<<endl;
 			}
 		}
 		cout<<endl;
@@ -528,13 +569,11 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (IllegalArgumentException *exc) {
+			catch (const util::IllegalArgumentException& exc) {
 				cout<<" X\t";
-				delete exc;
 			}
-			catch (GEOSException *exc) {
-				cerr<<exc->toString()<<endl;
-				delete exc;
+			catch (const std::exception& exc) {
+				cerr<<exc.what()<<endl;
 			}
 		}
 		cout<<endl;
@@ -560,13 +599,11 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (IllegalArgumentException *exc) {
+			catch (const util::IllegalArgumentException& exc) {
 				cout<<" X\t";
-				delete exc;
 			}
-			catch (GEOSException *exc) {
-				cerr<<exc->toString()<<endl;
-				delete exc;
+			catch (const std::exception& exc) {
+				cerr<<exc.what()<<endl;
 			}
 		}
 		cout<<endl;
@@ -592,13 +629,11 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (IllegalArgumentException *exc) {
+			catch (const util::IllegalArgumentException& exc) {
 				cout<<" X\t";
-				delete exc;
 			}
-			catch (GEOSException *exc) {
-				cerr<<exc->toString()<<endl;
-				delete exc;
+			catch (const std::exception& exc) {
+				cerr<<exc.what()<<endl;
 			}
 		}
 		cout<<endl;
@@ -624,13 +659,11 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (IllegalArgumentException *exc) {
+			catch (const util::IllegalArgumentException& exc) {
 				cout<<" X\t";
-				delete exc;
 			}
-			catch (GEOSException *exc) {
-				cerr<<exc->toString()<<endl;
-				delete exc;
+			catch (const std::exception& exc) {
+				cerr<<exc.what()<<endl;
 			}
 		}
 		cout<<endl;
@@ -656,13 +689,11 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (IllegalArgumentException *exc) {
+			catch (const util::IllegalArgumentException& exc) {
 				cout<<" X\t";
-				delete exc;
 			}
-			catch (GEOSException *exc) {
-				cerr<<exc->toString()<<endl;
-				delete exc;
+			catch (const std::exception& exc) {
+				cerr<<exc.what()<<endl;
 			}
 		}
 		cout<<endl;
@@ -688,13 +719,11 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (IllegalArgumentException *exc) {
+			catch (const util::IllegalArgumentException& exc) {
 				cout<<" X\t";
-				delete exc;
 			}
-			catch (GEOSException *exc) {
-				cerr<<exc->toString()<<endl;
-				delete exc;
+			catch (const std::exception& exc) {
+				cerr<<exc.what()<<endl;
 			}
 		}
 		cout<<endl;
@@ -718,7 +747,8 @@ cout<<"-------------------------------------------------------------------------
 			IntersectionMatrix *im=NULL;
 			try {
 				// second argument is intersectionPattern
-				if ( g1->relate(g2, "212101212") ) cout<<" 1\t";
+				string pattern = "212101212";
+				if ( g1->relate(g2, pattern) ) cout<<" 1\t";
 				else cout<<" 0\t";
 				
 				// get the intersectionMatrix itself
@@ -726,13 +756,11 @@ cout<<"-------------------------------------------------------------------------
 				delete im; // delete afterwards
 			}
 			// Geometry Collection is not a valid argument
-			catch (IllegalArgumentException *exc) {
+			catch (const util::IllegalArgumentException& exc) {
 				cout<<" X\t";
-				delete exc;
 			}
-			catch (GEOSException *exc) {
-				cerr<<exc->toString()<<endl;
-				delete exc;
+			catch (const std::exception& exc) {
+				cerr<<exc.what()<<endl;
 			}
 		}
 		cout<<endl;
@@ -758,13 +786,11 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (IllegalArgumentException *exc) {
+			catch (const util::IllegalArgumentException& exc) {
 				cout<<" X\t";
-				delete exc;
 			}
-			catch (GEOSException *exc) {
-				cerr<<exc->toString()<<endl;
-				delete exc;
+			catch (const std::exception& exc) {
+				cerr<<exc.what()<<endl;
 			}
 		}
 		cout<<endl;
@@ -791,13 +817,11 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (IllegalArgumentException *exc) {
+			catch (const util::IllegalArgumentException& exc) {
 				cout<<" X\t";
-				delete exc;
 			}
-			catch (GEOSException *exc) {
-				cerr<<exc->toString()<<endl;
-				delete exc;
+			catch (const std::exception& exc) {
+				cerr<<exc.what()<<endl;
 			}
 		}
 		cout<<endl;
@@ -824,18 +848,20 @@ cout<<"-------------------------------------------------------------------------
 				else cout<<" 0\t";
 			}
 			// Geometry Collection is not a valid argument
-			catch (IllegalArgumentException *exc) {
+			catch (const util::IllegalArgumentException& exc) {
 				cout<<" X\t";
-				delete exc;
 			}
-			catch (GEOSException *exc) {
-				cerr<<exc->toString()<<endl;
-				delete exc;
+			catch (const std::exception& exc) {
+				cerr<<exc.what()<<endl;
 			}
 		}
 		cout<<endl;
 	}
 
+#endif // RELATIONAL_OPERATORS
+
+#if COMBINATIONS
+
 ////////////////////////////////////////////////////////////////////////
 // COMBINATIONS
 ////////////////////////////////////////////////////////////////////////
@@ -860,13 +886,11 @@ cout<<"-------------------------------------------------------------------------
 				newgeoms->push_back(g3);
 			}
 			// It's illegal to union a collection ...
-			catch (IllegalArgumentException *ill) {
-				//cerr <<ill->toString()<<"\n";
-				delete ill;
+			catch (const util::IllegalArgumentException& ill) {
+				//cerr <<ill.toString()<<"\n";
 			}
-			catch (GEOSException *exc) {
-				cerr <<"GEOS Exception: "<<exc->toString()<<"\n";
-				delete exc;
+			catch (const std::exception& exc) {
+				cerr<<exc.what()<<endl;
 			}
 		}
 	}
@@ -897,13 +921,11 @@ cout<<"-------------------------------------------------------------------------
 				newgeoms->push_back(g3);
 			}
 			// Collection are illegal as intersection argument
-			catch (IllegalArgumentException *ill) {
-				//cerr <<ill->toString()<<"\n";
-				delete ill;
+			catch (const util::IllegalArgumentException& ill) {
+				//cerr <<ill.toString()<<"\n";
 			}
-			catch (GEOSException *exc) {
-				cerr <<"GEOS Exception: "<<exc->toString()<<"\n";
-				delete exc;
+			catch (const std::exception& exc) {
+				cerr<<exc.what()<<endl;
 			}
 		}
 	}
@@ -932,13 +954,11 @@ cout<<"-------------------------------------------------------------------------
 				newgeoms->push_back(g3);
 			}
 			// Collection are illegal as difference argument
-			catch (IllegalArgumentException *ill) {
-				//cerr <<ill->toString()<<"\n";
-				delete ill;
+			catch (const util::IllegalArgumentException& ill) {
+				//cerr <<ill.toString()<<"\n";
 			}
-			catch (GEOSException *exc) {
-				cerr <<"GEOS Exception: "<<exc->toString()<<"\n";
-				delete exc;
+			catch (const std::exception& exc) {
+				cerr<<exc.what()<<endl;
 			}
 		}
 	}
@@ -967,13 +987,11 @@ cout<<"-------------------------------------------------------------------------
 				newgeoms->push_back(g3);
 			}
 			// Collection are illegal as symdifference argument
-			catch (IllegalArgumentException *ill) {
-				//cerr <<ill->toString()<<"\n";
-				delete ill;
+			catch (const util::IllegalArgumentException& ill) {
+				//cerr <<ill.toString()<<"\n";
 			}
-			catch (GEOSException *exc) {
-				cerr <<"GEOS Exception: "<<exc->toString()<<"\n";
-				delete exc;
+			catch (const std::exception& exc) {
+				cerr<<exc.what()<<endl;
 			}
 		}
 	}
@@ -986,6 +1004,10 @@ cout<<"-------------------------------------------------------------------------
 		delete (*newgeoms)[i];
 	}
 	delete newgeoms;
+
+#endif // COMBINATIONS
+
+#if LINEMERGE
 	
 	/////////////////////////////////////////////
 	// LINEMERGE
@@ -1007,6 +1029,10 @@ cout<<"-------------------------------------------------------------------------
 	}
 	delete newgeoms;
 
+#endif // LINEMERGE
+
+#if POLYGONIZE
+
 	/////////////////////////////////////////////
 	// POLYGONIZE
 	/////////////////////////////////////////////
@@ -1027,6 +1053,8 @@ cout<<"-------------------------------------------------------------------------
 	}
 	delete newgeoms;
 
+#endif // POLYGONIZE
+
 	/////////////////////////////////////////////
 	// CLEANUP
 	/////////////////////////////////////////////
@@ -1050,13 +1078,12 @@ main()
 	}
 	// All exception thrown by GEOS are subclasses of this
 	// one, so this is a catch-all 
-	catch (GEOSException *exc)
+	catch (const util::GEOSException& exc)
 	{
-		cerr <<"GEOS Exception: "<<exc->toString()<<"\n";
-		delete exc;
+		cerr <<"GEOS Exception: "<<exc.what()<<"\n";
 		exit(1);
 	}
-	catch (exception &e)
+	catch (const exception &e)
 	{
 		cerr <<"Standard exception thrown: "<<e.what()<<endl;
 		exit(1);
@@ -1068,18 +1095,104 @@ main()
 		exit(1);
 	}
 
-	// This is not really needed but to make
-	// memory checker like valgrind quiet
-	// about static heap-allocated data.
-	Unload::Release();
+	// Unload is no more necessary
+	//io::Unload::Release();
 
 	exit(0);
 }
 
 /**********************************************************************
- * $Log: example.cpp,v $
- * Revision 1.26.4.1  2005/11/30 11:28:34  strk
- * Backported from HEAD, to test WKB io
+ * $Log$
+ * Revision 1.46  2006/04/09 11:07:54  mloskot
+ * Small fixes in doc/example.cpp.
+ *
+ * Revision 1.45  2006/04/04 08:16:46  strk
+ * Changed GEOSException hierarchy to be derived from std::runtime_exception.
+ * Removed the GEOSException::toString redundant method (use ::what() instead)
+ *
+ * Revision 1.44  2006/03/28 15:19:22  strk
+ * Added macros for sections skip (useful in debugging)
+ *
+ * Revision 1.43  2006/03/15 18:44:51  strk
+ * Bug #60 - Missing <cmath> header in some files
+ *
+ * Revision 1.42  2006/03/06 21:27:39  strk
+ * Cascading fixed after Unload definition moved to geos::io namespace
+ *
+ * Revision 1.41  2006/03/06 19:40:46  strk
+ * geos::util namespace. New GeometryCollection::iterator interface, many cleanups.
+ *
+ * Revision 1.40  2006/03/06 15:23:14  strk
+ * geos::io namespace
+ *
+ * Revision 1.39  2006/03/03 10:46:21  strk
+ * Removed 'using namespace' from headers, added missing headers in .cpp files, removed useless includes in headers (bug#46)
+ *
+ * Revision 1.38  2006/02/19 19:46:49  strk
+ * Packages <-> namespaces mapping for most GEOS internal code (uncomplete, but working). Dir-level libs for index/ subdirs.
+ *
+ * Revision 1.37  2006/02/09 15:52:47  strk
+ * GEOSException derived from std::exception; always thrown and cought by const ref.
+ *
+ * Revision 1.36  2006/01/31 19:07:33  strk
+ * - Renamed DefaultCoordinateSequence to CoordinateArraySequence.
+ * - Moved GetNumGeometries() and GetGeometryN() interfaces
+ *   from GeometryCollection to Geometry class.
+ * - Added getAt(int pos, Coordinate &to) funtion to CoordinateSequence class.
+ * - Reworked automake scripts to produce a static lib for each subdir and
+ *   then link all subsystem's libs togheter
+ * - Moved C-API in it's own top-level dir capi/
+ * - Moved source/bigtest and source/test to tests/bigtest and test/xmltester
+ * - Fixed PointLocator handling of LinearRings
+ * - Changed CoordinateArrayFilter to reduce memory copies
+ * - Changed UniqueCoordinateArrayFilter to reduce memory copies
+ * - Added CGAlgorithms::isPointInRing() version working with
+ *   Coordinate::ConstVect type (faster!)
+ * - Ported JTS-1.7 version of ConvexHull with big attention to
+ *   memory usage optimizations.
+ * - Improved XMLTester output and user interface
+ * - geos::geom::util namespace used for geom/util stuff
+ * - Improved memory use in geos::geom::util::PolygonExtractor
+ * - New ShortCircuitedGeometryVisitor class
+ * - New operation/predicate package
+ *
+ * Revision 1.35  2005/11/30 11:27:07  strk
+ * catch std::exception by ref
+ *
+ * Revision 1.34  2005/11/30 11:25:12  strk
+ * includes cleanup
+ *
+ * Revision 1.33  2005/09/27 16:20:43  strk
+ * Reverted previous change, fixed the bug by turning WKBReader.factory
+ * into a reference rather then a real object. ABI still breaks, but API
+ * at least is safe (we didn't release any WKB-aware package so breaking
+ * ABI is not a big deal at this stage).
+ *
+ * Revision 1.32  2005/09/27 16:00:26  strk
+ * Fixed bug in WKBReader destroying the GeometryFactory used in Geometry
+ * construction. Changed it's definition to *require* a GeometryFactory
+ * pointer parameter.
+ *
+ * Revision 1.31  2005/09/26 08:17:19  strk
+ * Removed memory leak from WKB tester
+ *
+ * Revision 1.30  2005/09/03 21:26:42  strk
+ * Reworked WKB I/O to avoid use of templates and make better use of STL
+ *
+ * Revision 1.29  2005/07/11 12:17:26  strk
+ * Commented out useless include
+ *
+ * Revision 1.28  2005/04/29 16:36:28  strk
+ * Made WKBReader use global_factory, for having WKB reads produce
+ * same context of input geoms.
+ *
+ * Revision 1.27  2005/04/29 15:34:20  strk
+ * Typedef'ed biostringstream, preferred parameter for
+ * WKB parser templates.
+ * Added << operator for biostringstream.
+ * Typedef'ed WKBWriter and WKBReader to be parametrized by
+ * biostringstream.
+ * Added WKBtest in doc/example.cpp
  *
  * Revision 1.26  2004/12/08 13:54:43  strk
  * gcc warnings checked and fixed, general cleanups.
