@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: Dimension.cpp,v 1.9.2.1 2005/05/23 18:41:51 strk Exp $
+ * $Id: Dimension.cpp 1820 2006-09-06 16:54:23Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -11,28 +11,17 @@
  * by the Free Software Foundation. 
  * See the COPYING file for more information.
  *
- **********************************************************************
- * $Log: Dimension.cpp,v $
- * Revision 1.9.2.1  2005/05/23 18:41:51  strk
- * Replaced sprintf uses with ostringstream
- *
- * Revision 1.9  2004/07/02 13:28:26  strk
- * Fixed all #include lines to reflect headers layout change.
- * Added client application build tips in README.
- *
- * Revision 1.8  2003/11/07 01:23:42  pramsey
- * Add standard CVS headers licence notices and copyrights to all cpp and h
- * files.
- *
- *
  **********************************************************************/
 
+#include <geos/geom/Dimension.h>
+#include <geos/util/IllegalArgumentException.h>
 
 #include <sstream>
-#include <geos/geom.h>
-#include <geos/util.h>
+
+using namespace std;
 
 namespace geos {
+namespace geom { // geos::geom
 
 /**
  *  Converts the dimension value to a dimension symbol, for example, <code>TRUE => 'T'</code>.
@@ -59,7 +48,7 @@ char Dimension::toDimensionSymbol(int dimensionValue) {
 		default:
 			ostringstream s;
 			s<<"Unknown dimension value: "<<dimensionValue<<endl;
-			throw new IllegalArgumentException(s.str());
+			throw  util::IllegalArgumentException(s.str());
 	}
 }
 
@@ -90,8 +79,44 @@ int Dimension::toDimensionValue(char dimensionSymbol) {
 		default:
 			ostringstream s;
 			s<<"Unknown dimension symbol: "<<dimensionSymbol<<endl;
-			throw new IllegalArgumentException(s.str());
+			throw  util::IllegalArgumentException(s.str());
 	}
 }
-}
+
+} // namespace geos::geom
+} // namespace geos
+
+/**********************************************************************
+ * $Log$
+ * Revision 1.15  2006/03/22 16:58:34  strk
+ * Removed (almost) all inclusions of geom.h.
+ * Removed obsoleted .cpp files.
+ * Fixed a bug in WKTReader not using the provided CoordinateSequence
+ * implementation, optimized out some memory allocations.
+ *
+ * Revision 1.14  2006/03/09 16:46:47  strk
+ * geos::geom namespace definition, first pass at headers split
+ *
+ * Revision 1.13  2006/03/06 19:40:46  strk
+ * geos::util namespace. New GeometryCollection::iterator interface, many cleanups.
+ *
+ * Revision 1.12  2006/03/03 10:46:21  strk
+ * Removed 'using namespace' from headers, added missing headers in .cpp files, removed useless includes in headers (bug#46)
+ *
+ * Revision 1.11  2006/02/09 15:52:47  strk
+ * GEOSException derived from std::exception; always thrown and cought by const ref.
+ *
+ * Revision 1.10  2005/01/28 09:47:51  strk
+ * Replaced sprintf uses with ostringstream.
+ *
+ * Revision 1.9  2004/07/02 13:28:26  strk
+ * Fixed all #include lines to reflect headers layout change.
+ * Added client application build tips in README.
+ *
+ * Revision 1.8  2003/11/07 01:23:42  pramsey
+ * Add standard CVS headers licence notices and copyrights to all cpp and h
+ * files.
+ *
+ *
+ **********************************************************************/
 
