@@ -1,10 +1,11 @@
 /**********************************************************************
- * $Id: GeometryGraph.cpp,v 1.10 2004/11/22 11:34:49 strk Exp $
+ * $Id: GeometryGraph.cpp 1820 2006-09-06 16:54:23Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
  *
  * Copyright (C) 2001-2002 Vivid Solutions Inc.
+ * Copyright (C) 2005 Refractions Research Inc.
  *
  * This is free software; you can redistribute and/or modify it under
  * the terms of the GNU Lesser General Public Licence as published
@@ -13,15 +14,53 @@
  *
  **********************************************************************/
 
-#include <geos/geomgraph.h>
-#include <typeinfo>
-#include <geos/util.h>
+#include <geos/algorithm/CGAlgorithms.h>
 
-#ifndef DEBUG
-#define DEBUG 0
+#include <geos/util/UnsupportedOperationException.h>
+
+#include <geos/geomgraph/GeometryGraph.h>
+#include <geos/geomgraph/Node.h>
+#include <geos/geomgraph/Edge.h>
+#include <geos/geomgraph/Label.h>
+#include <geos/geomgraph/Position.h>
+
+#include <geos/geomgraph/index/SimpleMCSweepLineIntersector.h> 
+#include <geos/geomgraph/index/SegmentIntersector.h> 
+#include <geos/geomgraph/index/EdgeSetIntersector.h>
+
+#include <geos/geom/CoordinateArraySequence.h> 
+#include <geos/geom/CoordinateSequence.h>
+#include <geos/geom/Location.h>
+#include <geos/geom/Point.h>
+#include <geos/geom/LinearRing.h>
+#include <geos/geom/LineString.h>
+#include <geos/geom/Polygon.h>
+#include <geos/geom/MultiPoint.h>
+#include <geos/geom/MultiLineString.h>
+#include <geos/geom/MultiPolygon.h>
+#include <geos/geom/GeometryCollection.h>
+
+#include <geos/inline.h>
+
+#include <vector>
+#include <memory> // auto_ptr
+#include <cassert>
+
+#ifndef GEOS_DEBUG
+#define GEOS_DEBUG 0
 #endif
 
+#ifndef GEOS_INLINE
+# include "geos/geomgraph/GeometryGraph.inl"
+#endif
+
+using namespace std;
+using namespace geos::geomgraph::index;
+using namespace geos::algorithm;
+using namespace geos::geom;
+
 namespace geos {
+namespace geomgraph { // geos.geomgraph
 
 /*
  * This method implements the Boundary Determination Rule
@@ -48,44 +87,6 @@ GeometryGraph::determineBoundary(int boundaryCount)
 	return isInBoundary(boundaryCount)?Location::BOUNDARY : Location::INTERIOR;
 }
 
-GeometryGraph::GeometryGraph():PlanarGraph()
-{
-	lineEdgeMap=new map<const LineString*,Edge*,LineStringLT>();
-	useBoundaryDeterminationRule=false;
-	boundaryNodes=NULL;
-	parentGeom=NULL;
-	hasTooFewPointsVar=false;
-}
-
-GeometryGraph::~GeometryGraph(){
-//	map<LineString*,Edge*,LineStringLT>::iterator it=lineEdgeMap->begin();
-//	for (;it!=lineEdgeMap->end();it++) {
-//		Edge *e=it->second;
-//		delete e;
-//	}
-	delete lineEdgeMap;
-}
-
-GeometryGraph::GeometryGraph(int newArgIndex, const Geometry *newParentGeom): PlanarGraph()
-{
-	hasTooFewPointsVar=false;
-	boundaryNodes=NULL;
-	lineEdgeMap=new map<const LineString*,Edge*,LineStringLT>();
-	useBoundaryDeterminationRule=false;
-	argIndex=newArgIndex;
-	parentGeom=newParentGeom;
-	if (parentGeom!=NULL) {
-		try
-		{
-			add(parentGeom);
-		}
-		catch(...)
-		{
-			delete lineEdgeMap;
-			throw;
-		}
-	}
-}
 
 EdgeSetIntersector*
 GeometryGraph::createEdgeSetIntersector()
@@ -102,76 +103,61 @@ GeometryGraph::createEdgeSetIntersector()
 	return new SimpleMCSweepLineIntersector();
 }
 
-//NO LONGER USED
-/**
-* This constructor is used by clients that wish to add Edges explicitly,
-* rather than adding a Geometry.  (An example is BufferOp).
-*/
-//GeometryGraph::GeometryGraph(int newArgIndex, const PrecisionModel *newPrecisionModel, int newSRID):PlanarGraph(){
-//	boundaryNodes=NULL;
-//	lineEdgeMap=new map<const LineString*,Edge*,LineStringLT>();
-//	useBoundaryDeterminationRule=false;
-//	argIndex=newArgIndex;
-//	parentGeom=NULL;
-//	precisionModel=newPrecisionModel;
-//	SRID=newSRID;
-//	hasTooFewPointsVar=false;
-//}
-//
-//const PrecisionModel* GeometryGraph::getPrecisionModel(){
-//	return precisionModel;
-//}
-//
-//int GeometryGraph::getSRID() {
-//	return SRID;
-//}
-
-const
-Geometry* GeometryGraph::getGeometry()
-{
-	return parentGeom;
-}
-
+/*public*/
 vector<Node*>*
 GeometryGraph::getBoundaryNodes()
 {
-	if (boundaryNodes==NULL)
-		boundaryNodes=nodes->getBoundaryNodes(argIndex);
-	return boundaryNodes;
+	if ( ! boundaryNodes.get() )
+	{
+		boundaryNodes.reset(new vector<Node*>());
+		getBoundaryNodes(*(boundaryNodes.get()));
+	}
+	return boundaryNodes.get();
 }
 
+/*public*/
 CoordinateSequence*
 GeometryGraph::getBoundaryPoints()
 {
-	vector<Node*> *coll=getBoundaryNodes();
-	CoordinateSequence *pts=new DefaultCoordinateSequence((int)coll->size());
-	int i=0;
-	for (vector<Node*>::iterator it=coll->begin();it<coll->end();it++) {
-		Node *node=*it;
-		pts->setAt(node->getCoordinate(),i++);
+
+	if ( ! boundaryPoints.get() ) 
+	{
+		// Collection will be destroied by GeometryGraph dtor
+		vector<Node*>* coll = getBoundaryNodes();
+		boundaryPoints.reset(new CoordinateArraySequence(coll->size()));
+		size_t i=0;
+		for (vector<Node*>::iterator it=coll->begin(), endIt=coll->end();
+			it!=endIt; ++it)
+		{
+			Node *node=*it;
+			boundaryPoints->setAt(node->getCoordinate(), i++);
+		}
 	}
-	delete coll;
-	return pts;
+
+	// We keep ownership of this, will be destroyed by destructor
+	return boundaryPoints.get();
 }
 
 Edge*
 GeometryGraph::findEdge(const LineString *line)
 {
-	return lineEdgeMap->find(line)->second;
+	return lineEdgeMap.find(line)->second;
 }
 
 void
 GeometryGraph::computeSplitEdges(vector<Edge*> *edgelist)
 {
-#if DEBUG
+#if GEOS_DEBUG
 	cerr<<"["<<this<<"] GeometryGraph::computeSplitEdges() scanning "<<edges->size()<<" local and "<<edgelist->size()<<" provided edges"<<endl;
 #endif
-	for (vector<Edge*>::iterator i=edges->begin();i<edges->end();i++) {
+	for (vector<Edge*>::iterator i=edges->begin(), endIt=edges->end();
+		i!=endIt; ++i)
+	{
 		Edge *e=*i;
-#if DEBUG
+#if GEOS_DEBUG
 		cerr<<"   "<<e->print()<<" adding split edges from arg"<<endl;
 #endif
-		e->eiList->addSplitEdges(edgelist);
+		e->eiList.addSplitEdges(edgelist);
 	}
 }
 
@@ -205,14 +191,15 @@ GeometryGraph::add(const Geometry *g)
 		addCollection((GeometryCollection*) g);
 	else {
 		string out=typeid(*g).name();
-		throw new UnsupportedOperationException("GeometryGraph::add(Geometry *): unknown geometry type: "+out);
+		throw util::UnsupportedOperationException("GeometryGraph::add(Geometry *): unknown geometry type: "+out);
 	}
 }
 
 void
 GeometryGraph::addCollection(const GeometryCollection *gc)
 {
-	for (int i=0;i<gc->getNumGeometries();i++) {
+	for (size_t i=0, n=gc->getNumGeometries(); i<n; ++i)
+	{
 		const Geometry *g=gc->getGeometryN(i);
 		add(g);
 	}
@@ -225,7 +212,7 @@ void
 GeometryGraph::addPoint(const Point *p)
 {
 	const Coordinate& coord=*(p->getCoordinate());
-	insertPoint(argIndex,coord,Location::INTERIOR);
+	insertPoint(argIndex, coord, Location::INTERIOR);
 }
 
 /*
@@ -257,7 +244,7 @@ GeometryGraph::addPolygonRing(const LinearRing *lr, int cwLeft, int cwRight)
 	 */
 	try
 	{
-		if (cga->isCCW(coord)) {
+		if (CGAlgorithms::isCCW(coord)) {
 			left=cwRight;
 			right=cwLeft;
 		}
@@ -269,7 +256,7 @@ GeometryGraph::addPolygonRing(const LinearRing *lr, int cwLeft, int cwRight)
 	}
 
 	Edge *e=new Edge(coord,new Label(argIndex,Location::BOUNDARY,left,right));
-	(*lineEdgeMap)[lr]=e;
+	lineEdgeMap[lr]=e;
 	insertEdge(e);
 	insertPoint(argIndex,coord->getAt(0), Location::BOUNDARY);
 }
@@ -277,12 +264,22 @@ GeometryGraph::addPolygonRing(const LinearRing *lr, int cwLeft, int cwRight)
 void
 GeometryGraph::addPolygon(const Polygon *p)
 {
-	addPolygonRing((LinearRing*) p->getExteriorRing(),Location::EXTERIOR,Location::INTERIOR);
-	for (int i=0;i<p->getNumInteriorRing();i++) {
+	const LineString* ls;
+	const LinearRing* lr;
+
+	ls = p->getExteriorRing();
+	assert(dynamic_cast<const LinearRing*>(ls));
+	lr = static_cast<const LinearRing*>(ls);
+	addPolygonRing(lr, Location::EXTERIOR, Location::INTERIOR);
+	for (size_t i=0, n=p->getNumInteriorRing(); i<n; ++i)
+	{
 		// Holes are topologically labelled opposite to the shell, since
 		// the interior of the polygon lies on their opposite side
 		// (on the left, if the hole is oriented CW)
-		addPolygonRing((LinearRing*) p->getInteriorRingN(i),Location::INTERIOR,Location::EXTERIOR);
+		ls = p->getInteriorRingN(i);
+		assert(dynamic_cast<const LinearRing*>(ls));
+		lr = static_cast<const LinearRing*>(ls);
+		addPolygonRing(lr, Location::INTERIOR, Location::EXTERIOR);
 	}
 }
 
@@ -297,17 +294,8 @@ GeometryGraph::addLineString(const LineString *line)
 		return;
 	}
 
-	// add the edge for the LineString
-	// line edges do not have locations for their left and right sides
-	//CoordinateSequence *ncr=CoordinateSequenceFactory::internalFactory->createCoordinateSequence();
-	//for(int i=0;i<coord->getSize();i++) {
-		//ncr->add(coord->getAt(i));
-	//}
-	//CoordinateSequence *ncr = coord->clone();
-
-//	Edge *e=new Edge(ncr,new Label(argIndex,Location::INTERIOR));
 	Edge *e=new Edge(coord,new Label(argIndex,Location::INTERIOR));
-	(*lineEdgeMap)[line]=e;
+	lineEdgeMap[line]=e;
 	insertEdge(e);
 
 	/*
@@ -317,10 +305,9 @@ GeometryGraph::addLineString(const LineString *line)
 	 * This allows for the case that the node already exists and is
 	 * a boundary point.
 	 */
-	Assert::isTrue(coord->getSize()>= 2,"found LineString with single point");
+	assert(coord->size() >= 2); // found LineString with single point
 	insertBoundaryPoint(argIndex, coord->getAt(0));
 	insertBoundaryPoint(argIndex, coord->getAt(coord->getSize()-1));
-//	delete coord;
 }
 
 /*
@@ -347,16 +334,7 @@ GeometryGraph::addPoint(Coordinate& pt)
 	insertPoint(argIndex,pt,Location::INTERIOR);
 }
 
-/*
- * Compute self-nodes, taking advantage of the Geometry type to
- * minimize the number of intersection tests.  (E.g. rings are
- * not tested for self-intersection, since they are assumed to be valid).
- * @param li the LineIntersector to use
- * @param computeRingSelfNodes if <false>, intersection checks are
- *	optimized to not test rings for self-intersection
- * @return the SegmentIntersector used, containing information about
- *	the intersections found
- */
+/*public*/
 SegmentIntersector*
 GeometryGraph::computeSelfNodes(LineIntersector *li, bool computeRingSelfNodes)
 {
@@ -375,7 +353,11 @@ GeometryGraph::computeSelfNodes(LineIntersector *li, bool computeRingSelfNodes)
 	{
 		esi->computeIntersections(edges, si, true);
 	}
-	//System.out.println("SegmentIntersector # tests = " + si.numTests);
+
+#if GEOS_DEBUG
+	cerr << "SegmentIntersector # tests = " << si->numTests << endl;
+#endif // GEOS_DEBUG
+
 	addSelfIntersectionNodes(argIndex);
 	return si;
 }
@@ -384,31 +366,38 @@ SegmentIntersector*
 GeometryGraph::computeEdgeIntersections(GeometryGraph *g,
 	LineIntersector *li, bool includeProper)
 {
-#if DEBUG
+#if GEOS_DEBUG
 	cerr<<"GeometryGraph::computeEdgeIntersections call"<<endl;
 #endif
 	SegmentIntersector *si=new SegmentIntersector(li, includeProper, true);
+	newSegmentIntersectors.push_back(si);
+
 	si->setBoundaryNodes(getBoundaryNodes(), g->getBoundaryNodes());
 	auto_ptr<EdgeSetIntersector> esi(createEdgeSetIntersector());
 	esi->computeIntersections(edges, g->edges, si);
-#if DEBUG
+#if GEOS_DEBUG
 	cerr<<"GeometryGraph::computeEdgeIntersections returns"<<endl;
 #endif
 	return si;
 }
 
 void
-GeometryGraph::insertPoint(int argIndex,const Coordinate& coord, int onLocation)
+GeometryGraph::insertPoint(int argIndex, const Coordinate& coord,
+	int onLocation)
 {
-#if DEBUG
+#if GEOS_DEBUG
 	cerr<<"GeometryGraph::insertPoint("<<coord.toString()<<" called"<<endl;
 #endif
 	Node *n=nodes->addNode(coord);
 	Label *lbl=n->getLabel();
-	if (lbl==NULL) {
-		n->setLabel(argIndex,onLocation);
-	} else
-		lbl->setLocation(argIndex,onLocation);
+	if (lbl==NULL)
+	{
+		n->setLabel(argIndex, onLocation);
+	}
+	else
+	{
+		lbl->setLocation(argIndex, onLocation);
+	}
 }
 
 /*
@@ -422,46 +411,55 @@ GeometryGraph::insertBoundaryPoint(int argIndex,const Coordinate& coord)
 {
 	Node *n=nodes->addNode(coord);
 	Label *lbl=n->getLabel();
+
 	// the new point to insert is on a boundary
 	int boundaryCount=1;
 	// determine the current location for the point (if any)
 	int loc=Location::UNDEF;
 	if (lbl!=NULL) loc=lbl->getLocation(argIndex,Position::ON);
 	if (loc==Location::BOUNDARY) boundaryCount++;
-	// determine the boundary status of the point according to the Boundary Determination Rule
+
+	// determine the boundary status of the point according to the
+	// Boundary Determination Rule
 	int newLoc=determineBoundary(boundaryCount);
 	lbl->setLocation(argIndex,newLoc);
 }
 
+/*private*/
 void
 GeometryGraph::addSelfIntersectionNodes(int argIndex)
 {
-	for (vector<Edge*>::iterator i=edges->begin();i<edges->end();i++) {
+	for (vector<Edge*>::iterator i=edges->begin(), endIt=edges->end();
+		i!=endIt; ++i)
+	{
 		Edge *e=*i;
 		int eLoc=e->getLabel()->getLocation(argIndex);
-		vector<EdgeIntersection*> *eil=e->eiList->list;
-		for (vector<EdgeIntersection*>::iterator eiIt=eil->begin();eiIt<eil->end();eiIt++) {
+		EdgeIntersectionList &eiL=e->eiList;
+		for (EdgeIntersectionList::iterator
+			eiIt=eiL.begin(), eiEnd=eiL.end();
+			eiIt!=eiEnd; ++eiIt)
+		{
 			EdgeIntersection *ei=*eiIt;
-			addSelfIntersectionNode(argIndex,ei->coord,eLoc);
+			addSelfIntersectionNode(argIndex, ei->coord, eLoc);
 		}
 	}
 }
 
-/*
- * Add a node for a self-intersection.
- * If the node is a potential boundary node (e.g. came from an edge which
- * is a boundary) then insert it as a potential boundary node.
- * Otherwise, just add it as a regular node.
- */
+/*private*/
 void
-GeometryGraph::addSelfIntersectionNode(int argIndex,Coordinate& coord,int loc)
+GeometryGraph::addSelfIntersectionNode(int argIndex,
+	const Coordinate& coord, int loc)
 {
 	// if this node is already a boundary node, don't change it
 	if (isBoundaryNode(argIndex,coord)) return;
 	if (loc==Location::BOUNDARY && useBoundaryDeterminationRule)
+	{
 		insertBoundaryPoint(argIndex,coord);
+	}
 	else
+	{
 		insertPoint(argIndex,coord,loc);
+	}
 }
 
 vector<Edge*> *
@@ -482,63 +480,29 @@ GeometryGraph::getInvalidPoint()
 	return invalidPoint;
 }
 
-}
+} // namespace geos.geomgraph
+} // namespace geos
 
 /**********************************************************************
- * $Log: GeometryGraph.cpp,v $
- * Revision 1.10  2004/11/22 11:34:49  strk
- * More debugging lines and comments/indentation cleanups
+ * $Log$
+ * Revision 1.30  2006/06/13 21:40:06  strk
+ * Cleanups and some more debugging lines
  *
- * Revision 1.9  2004/11/19 09:33:55  strk
- * removed useless CoordinateSequence copy in ::addLineString
+ * Revision 1.29  2006/06/12 11:29:23  strk
+ * unsigned int => size_t
  *
- * Revision 1.8  2004/11/05 11:41:57  strk
- * Made IsValidOp handle IllegalArgumentException throw from GeometryGraph
- * as a sign of invalidity (just for Polygon geometries).
- * Removed leaks generated by this specific exception.
+ * Revision 1.28  2006/06/09 07:42:13  strk
+ * * source/geomgraph/GeometryGraph.cpp, source/operation/buffer/OffsetCurveSetBuilder.cpp, source/operation/overlay/OverlayOp.cpp, source/operation/valid/RepeatedPointTester.cpp: Fixed warning after Polygon ring accessor methods changed to work with size_t. Small optimizations in loops.
  *
- * Revision 1.7  2004/10/21 22:29:54  strk
- * Indentation changes and some more COMPUTE_Z rules
+ * Revision 1.27  2006/04/07 09:54:30  strk
+ * Geometry::getNumGeometries() changed to return 'unsigned int'
+ * rather then 'int'
  *
- * Revision 1.6  2004/10/20 17:32:14  strk
- * Initial approach to 2.5d intersection()
+ * Revision 1.26  2006/03/29 15:23:49  strk
+ * Moved GeometryGraph inlines from .h to .inl file
  *
- * Revision 1.5  2004/10/19 19:51:14  strk
- * Fixed many leaks and bugs in Polygonizer.
- * Output still bogus.
- *
- * Revision 1.4  2004/07/08 19:34:49  strk
- * Mirrored JTS interface of CoordinateSequence, factory and
- * default implementations.
- * Added DefaultCoordinateSequenceFactory::instance() function.
- *
- * Revision 1.3  2004/07/02 13:28:26  strk
- * Fixed all #include lines to reflect headers layout change.
- * Added client application build tips in README.
- *
- * Revision 1.2  2004/05/03 10:43:42  strk
- * Exception specification considered harmful - left as comment.
- *
- * Revision 1.1  2004/03/19 09:48:45  ybychkov
- * "geomgraph" and "geomgraph/indexl" upgraded to JTS 1.4
- *
- * Revision 1.33  2003/11/12 15:43:38  strk
- * Added some more throw specifications
- *
- * Revision 1.32  2003/11/07 01:23:42  pramsey
- * Add standard CVS headers licence notices and copyrights to all cpp and h
- * files.
- *
- * Revision 1.31  2003/10/20 13:53:03  strk
- * LinearRing handled as a LineString in 
- * GeometryGraph::add(const Geometry *) - more explicit exception 
- * thrown for unknown geometries
- *
- * Revision 1.30  2003/10/15 16:39:03  strk
- * Made Edge::getCoordinates() return a 'const' value. Adapted code set.
- *
- * Revision 1.29  2003/10/15 11:24:28  strk
- * Use getCoordinatesRO() introduced.
+ * Revision 1.25  2006/03/15 17:16:29  strk
+ * streamlined headers inclusion
  *
  **********************************************************************/
 
