@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: MonotoneChainOverlapAction.cpp,v 1.8 2004/12/08 13:54:43 strk Exp $
+ * $Id: MonotoneChainOverlapAction.cpp 1820 2006-09-06 16:54:23Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -13,16 +13,23 @@
  *
  **********************************************************************/
 
-#include <geos/indexChain.h>
-#include <stdio.h>
+#include <geos/index/chain/MonotoneChainOverlapAction.h>
+#include <geos/index/chain/MonotoneChain.h>
+#include <geos/geom/Envelope.h>
+#include <geos/geom/LineSegment.h>
+#include <geos/profiler.h>
+
+//#include <stdio.h>
 
 namespace geos {
+namespace index { // geos.index
+namespace chain { // geos.index.chain
 
 MonotoneChainOverlapAction::MonotoneChainOverlapAction() {
-	overlapSeg1=new LineSegment();
-	overlapSeg2=new LineSegment();
-	tempEnv1=new Envelope();
-	tempEnv2=new Envelope();
+	overlapSeg1=new geom::LineSegment();
+	overlapSeg2=new geom::LineSegment();
+	tempEnv1=new geom::Envelope();
+	tempEnv2=new geom::Envelope();
 
 }
 
@@ -37,30 +44,23 @@ MonotoneChainOverlapAction::~MonotoneChainOverlapAction() {
 /**
  * This function can be overridden if the original chains are needed
  */
-void MonotoneChainOverlapAction::overlap(indexMonotoneChain *mc1,int start1,indexMonotoneChain *mc2,int start2) {
+void
+MonotoneChainOverlapAction::overlap(MonotoneChain *mc1, int start1,
+		MonotoneChain *mc2, int start2)
+{
 	mc1->getLineSegment(start1,overlapSeg1);
 	mc2->getLineSegment(start2,overlapSeg2);
 	overlap(overlapSeg1,overlapSeg2);
 }
 
+} // namespace geos.index.chain
+} // namespace geos.index
 } // namespace geos
 
 /**********************************************************************
- * $Log: MonotoneChainOverlapAction.cpp,v $
- * Revision 1.8  2004/12/08 13:54:43  strk
- * gcc warnings checked and fixed, general cleanups.
- *
- * Revision 1.7  2004/07/02 13:28:27  strk
- * Fixed all #include lines to reflect headers layout change.
- * Added client application build tips in README.
- *
- * Revision 1.6  2004/03/25 02:23:55  ybychkov
- * All "index/" packages upgraded to JTS 1.4
- *
- * Revision 1.5  2003/11/07 01:23:42  pramsey
- * Add standard CVS headers licence notices and copyrights to all cpp and h
- * files.
- *
+ * $Log$
+ * Revision 1.11  2006/03/22 18:12:32  strk
+ * indexChain.h header split.
  *
  **********************************************************************/
 
