@@ -1,9 +1,10 @@
 /**********************************************************************
- * $Id: AbstractNode.cpp,v 1.8 2004/12/08 13:54:43 strk Exp $
+ * $Id: AbstractNode.cpp 1971 2007-02-07 00:34:26Z strk $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
  *
+ * Copyright (C) 2006 Refractions Research Inc.
  * Copyright (C) 2001-2002 Vivid Solutions Inc.
  *
  * This is free software; you can redistribute and/or modify it under
@@ -13,19 +14,25 @@
  *
  **********************************************************************/
 
-#include <geos/indexStrtree.h>
-#include <geos/util.h>
-#include <stdio.h>
+#include <geos/index/strtree/AbstractNode.h>
+
+#include <vector>
+#include <cassert>
+
+using namespace std;
 
 namespace geos {
+namespace index { // geos.index
+namespace strtree { // geos.index.strtree
 
 /*
  * Constructs an AbstractNode at the given level in the tree
  * @param level 0 if this node is a leaf, 1 if a parent of a leaf, and so on;
  * the root node will have the highest level
  */
-AbstractNode::AbstractNode(int newLevel) {
-	childBoundables=new vector<Boundable*>();
+AbstractNode::AbstractNode(int newLevel, int capacity) {
+	childBoundables=new std::vector<Boundable*>();
+	childBoundables->reserve(capacity);
 	bounds=NULL;
 	level=newLevel;
 }
@@ -38,12 +45,12 @@ AbstractNode::~AbstractNode() {
 * Returns either child AbstractNodes, or if this is a leaf node, real data (wrapped
 * in ItemBoundables).
 */
-vector<Boundable*>* AbstractNode::getChildBoundables() {
-	return childBoundables;
-}
+//vector<Boundable*>* AbstractNode::getChildBoundables() {
+	//return childBoundables;
+//}
 
 const void *
-AbstractNode::getBounds()
+AbstractNode::getBounds() const
 {
 	if (bounds==NULL) {
 		bounds = computeBounds();
@@ -60,37 +67,25 @@ int AbstractNode::getLevel() {
 }
 
 /**
-* Adds either an AbstractNode, or if this is a leaf node, a data object
-* (wrapped in an ItemBoundable)
-*/
+ * Adds either an AbstractNode, or if this is a leaf node, a data object
+ * (wrapped in an ItemBoundable)
+ */
 void AbstractNode::addChildBoundable(Boundable *childBoundable) {
-	Assert::isTrue(bounds==NULL);
+	assert(bounds==NULL);
 	childBoundables->push_back(childBoundable);
 }
 
+} // namespace geos.index.strtree
+} // namespace geos.index
 } // namespace geos
 
 /**********************************************************************
- * $Log: AbstractNode.cpp,v $
- * Revision 1.8  2004/12/08 13:54:43  strk
- * gcc warnings checked and fixed, general cleanups.
- *
- * Revision 1.7  2004/07/27 16:35:46  strk
- * Geometry::getEnvelopeInternal() changed to return a const Envelope *.
- * This should reduce object copies as once computed the envelope of a
- * geometry remains the same.
- *
- * Revision 1.6  2004/07/02 13:28:27  strk
- * Fixed all #include lines to reflect headers layout change.
- * Added client application build tips in README.
- *
- * Revision 1.5  2004/03/25 02:23:55  ybychkov
- * All "index/" packages upgraded to JTS 1.4
- *
- * Revision 1.4  2003/11/07 01:23:42  pramsey
- * Add standard CVS headers licence notices and copyrights to all cpp and h
- * files.
+ * $Log$
+ * Revision 1.13  2006/03/21 10:47:34  strk
+ * indexStrtree.h split
  *
+ * Revision 1.12  2006/03/06 19:40:47  strk
+ * geos::util namespace. New GeometryCollection::iterator interface, many cleanups.
  *
  **********************************************************************/
 
