@@ -1,9 +1,10 @@
 /**********************************************************************
- * $Id: WKTWriter.cpp,v 1.21 2004/12/08 13:54:43 strk Exp $
+ * $Id: WKTWriter.cpp 1820 2006-09-06 16:54:23Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
  *
+ * Copyright (C) 2005-2006 Refractions Research Inc.
  * Copyright (C) 2001-2002 Vivid Solutions Inc.
  *
  * This is free software; you can redistribute and/or modify it under
@@ -13,14 +14,32 @@
  *
  **********************************************************************/
 
-#include <geos/io.h>
-#include <geos/util.h>
+#include <geos/io/WKTWriter.h>
+#include <geos/io/Writer.h>
+#include <geos/geom/Coordinate.h>
+#include <geos/geom/Point.h>
+#include <geos/geom/LinearRing.h>
+#include <geos/geom/LineString.h>
+#include <geos/geom/Polygon.h>
+#include <geos/geom/MultiPoint.h>
+#include <geos/geom/MultiLineString.h>
+#include <geos/geom/MultiPolygon.h>
+#include <geos/geom/CoordinateSequence.h>
+#include <geos/geom/PrecisionModel.h>
+
 #include <typeinfo>
-#include <stdio.h>
+#include <cstdio> // should avoid this
+#include <string>
+#include <sstream>
+#include <cassert>
 
 #define PRINT_Z 0
 
+using namespace std;
+using namespace geos::geom;
+
 namespace geos {
+namespace io { // geos.io
 
 WKTWriter::WKTWriter() {
 	isFormatted=false;
@@ -30,10 +49,69 @@ WKTWriter::WKTWriter() {
 
 WKTWriter::~WKTWriter() {}
 
-string WKTWriter::createFormatter(const PrecisionModel* precisionModel) {
+/*static*/
+string
+WKTWriter::toLineString(const CoordinateSequence& seq)
+{
+	stringstream buf("LINESTRING ", ios_base::in|ios_base::out);
+	unsigned int npts = seq.getSize();
+	if ( npts == 0 )
+	{
+		buf << "EMPTY";
+	}
+	else
+	{
+		buf << "(";
+		for (unsigned int i=0; i<npts; ++i)
+		{
+			if (i) buf << ", ";
+			buf << seq.getX(i) << " " << seq.getY(i);
+#if PRINT_Z
+			buf << seq.getZ(i);
+#endif
+		}
+		buf << ")";
+	}
+
+	return buf.str();
+}
+
+/*static*/
+string
+WKTWriter::toLineString(const Coordinate& p0, const Coordinate& p1)
+{
+	stringstream ret("LINESTRING (", ios_base::in|ios_base::out);
+	ret << p0.x << " " << p0.y;
+#if PRINT_Z
+	ret << " " << p0.z;
+#endif
+	ret << ", " << p1.x << " " << p1.y;
+#if PRINT_Z
+	ret << " " << p1.z;
+#endif
+
+	return ret.str();
+}
+
+/*static*/
+string
+WKTWriter::toPoint(const Coordinate& p0)
+{
+	stringstream ret("POINT (", ios_base::in|ios_base::out);
+#if PRINT_Z
+	ret << p0.x << " " << p0.y  << " " << p0.z << " )";
+#else
+	ret << p0.x << " " << p0.y  << " )";
+#endif
+	return ret.str();
+}
+
+string
+WKTWriter::createFormatter(const PrecisionModel* precisionModel)
+{
 	// the default number of decimal places is 16, which is sufficient
 	// to accomodate the maximum precision of a double.
-    int decimalPlaces = precisionModel->getMaximumSignificantDigits();
+	int decimalPlaces = precisionModel->getMaximumSignificantDigits();
 	string fmt="%.";
 	char buffer[255];
 	sprintf(buffer,"%i",decimalPlaces);
@@ -52,7 +130,7 @@ string WKTWriter::write(const Geometry *geometry) {
 	Writer sw;
 //	try {
 		writeFormatted(geometry,false,&sw);
-//	} catch (IOException ex) {
+//	} catch (const IOException ex) {
 //		Assert::shouldNeverReachHere();
 //	}
 	string res=sw.toString();
@@ -64,13 +142,9 @@ void WKTWriter::write(const Geometry *geometry, Writer *writer) {
 }
 
 string WKTWriter::writeFormatted(const Geometry *geometry) {
-	Writer *sw=new Writer();
-//	try {
-		writeFormatted(geometry, true, sw);
-//	}catch (IOException ex) {
-//		Assert::shouldNeverReachHere();
-//	}
-	return sw->toString();
+	Writer sw;
+	writeFormatted(geometry, true, &sw);
+	return sw.toString();
 }
 
 void WKTWriter::writeFormatted(const Geometry *geometry, Writer *writer) {
@@ -83,11 +157,14 @@ void WKTWriter::writeFormatted(const Geometry *geometry, bool isFormatted, Write
 	appendGeometryTaggedText(geometry, 0, writer);
 }
 
-void WKTWriter::appendGeometryTaggedText(const Geometry *geometry, int level, Writer *writer) {
+void
+WKTWriter::appendGeometryTaggedText(const Geometry *geometry, int level,
+		Writer *writer)
+{
 	indent(level, writer);
 	if (typeid(*geometry)==typeid(Point)) {
 		Point* point=(Point*)geometry;
-		appendPointTaggedText(point->getCoordinate(),level,writer,point->getPrecisionModel());
+		appendPointTaggedText(point->getCoordinate(),level,writer);
 	} else if (typeid(*geometry)==typeid(LinearRing)) {
 		appendLinearRingTaggedText((LinearRing*) geometry, level, writer);
 	} else if (typeid(*geometry)==typeid(LineString)) {
@@ -105,19 +182,23 @@ void WKTWriter::appendGeometryTaggedText(const Geometry *geometry, int level, Wr
 	} else if (typeid(*geometry)==typeid(GeometryCollection)) {
 		appendGeometryCollectionTaggedText((GeometryCollection*)geometry, level, writer);
 	} else {
-//		Assert.shouldNeverReachHere("Unsupported Geometry implementation:" + geometry->getClass());
-		Assert::shouldNeverReachHere("Unsupported Geometry implementation");
+		assert(0); // Unsupported Geometry implementation
 	}
 }
 
+/*protected*/
 void
 WKTWriter::appendPointTaggedText(const Coordinate* coordinate, int level,
-		Writer *writer, const PrecisionModel* precisionModel) {
+		Writer *writer)
+{
 	writer->write("POINT ");
-	appendPointText(coordinate, level, writer, precisionModel);
+	appendPointText(coordinate, level, writer);
 }
 
-void WKTWriter::appendLineStringTaggedText(const LineString *lineString, int level, Writer *writer) {
+void
+WKTWriter::appendLineStringTaggedText(const LineString *lineString, int level,
+		Writer *writer)
+{
 	writer->write("LINESTRING ");
 	appendLineStringText(lineString, level, false, writer);
 }
@@ -160,20 +241,22 @@ void WKTWriter::appendGeometryCollectionTaggedText(const GeometryCollection *geo
 }
 
 void
-WKTWriter::appendPointText(const Coordinate* coordinate, int level,
-		Writer *writer,const PrecisionModel* precisionModel) {
+WKTWriter::appendPointText(const Coordinate* coordinate, int /*level*/,
+		Writer *writer)
+{
 	if (coordinate==NULL) {
 		writer->write("EMPTY");
 	} else {
 		writer->write("(");
-		appendCoordinate(coordinate, writer, precisionModel);
+		appendCoordinate(coordinate, writer);
 		writer->write(")");
 	}
 }
 
-void WKTWriter::appendCoordinate(const Coordinate* coordinate, Writer *writer, const PrecisionModel* precisionModel) {
-//	Coordinate* externalCoordinate=new Coordinate();
-//	precisionModel->toExternal(*coordinate, externalCoordinate);
+void
+WKTWriter::appendCoordinate(const Coordinate* coordinate,
+		Writer *writer)
+{
 	string out="";
 	out+=writeNumber(coordinate->x);
 	out+=" ";
@@ -183,7 +266,6 @@ void WKTWriter::appendCoordinate(const Coordinate* coordinate, Writer *writer, c
 	out+=writeNumber(coordinate->z);
 #endif
 	writer->write(out);
-//	delete externalCoordinate;
 }
 
 string WKTWriter::writeNumber(double d) {
@@ -195,31 +277,39 @@ string WKTWriter::writeNumber(double d) {
 	return out;
 }
 
-void WKTWriter::appendLineStringText(const LineString *lineString, int level, bool doIndent, Writer *writer) {
+void
+WKTWriter::appendLineStringText(const LineString *lineString, int level,
+		bool doIndent, Writer *writer)
+{
 	if (lineString->isEmpty()) {
 		writer->write("EMPTY");
 	} else {
 		if (doIndent) indent(level, writer);
 		writer->write("(");
-		for(int i=0;i<lineString->getNumPoints();i++) {
+		for(size_t i=0, n=lineString->getNumPoints(); i<n; ++i)
+		{
 			if (i>0) {
 				writer->write(", ");
 				if (i%10==0) indent(level + 2, writer);
 			}
-			appendCoordinate(&(lineString->getCoordinateN(i)), writer, lineString->getPrecisionModel());
+			appendCoordinate(&(lineString->getCoordinateN(i)), writer);
 		}
 		writer->write(")");
 	}
 }
 
-void WKTWriter::appendPolygonText(const Polygon *polygon, int level, bool indentFirst, Writer *writer) {
+void
+WKTWriter::appendPolygonText(const Polygon *polygon, int /*level*/,
+		bool indentFirst, Writer *writer)
+{
 	if (polygon->isEmpty()) {
 		writer->write("EMPTY");
 	} else {
 		if (indentFirst) indent(level, writer);
 		writer->write("(");
 		appendLineStringText(polygon->getExteriorRing(), level, false, writer);
-		for (int i=0; i<polygon->getNumInteriorRing(); i++) {
+		for (size_t i=0, n=polygon->getNumInteriorRing(); i<n; ++i)
+		{
 			writer->write(", ");
 			const LineString *ls=polygon->getInteriorRingN(i);
 			appendLineStringText(ls, level + 1, true, writer);
@@ -228,17 +318,24 @@ void WKTWriter::appendPolygonText(const Polygon *polygon, int level, bool indent
 	}
 }
 
-void WKTWriter::appendMultiPointText(const MultiPoint *multiPoint, int level, Writer *writer) {
+void
+WKTWriter::appendMultiPointText(const MultiPoint *multiPoint,
+		int /*level*/, Writer *writer)
+{
 	if (multiPoint->isEmpty()) {
 		writer->write("EMPTY");
 	} else {
 		writer->write("(");
-		for (int i=0; i<multiPoint->getNumGeometries(); i++) {
-			if (i > 0) {
+		for (unsigned int i=0, n=multiPoint->getNumGeometries();
+				i<n; i++)
+		{
+			if (i > 0)
+			{
 				writer->write(", ");
 			}
-			appendCoordinate(((Point* )multiPoint->getGeometryN(i))->getCoordinate(), writer,
-							  multiPoint->getPrecisionModel());
+			appendCoordinate(
+				((Point* )multiPoint->getGeometryN(i))->getCoordinate(),
+				writer);
 		}
 		writer->write(")");
 	}
@@ -252,7 +349,9 @@ void WKTWriter::appendMultiLineStringText(const MultiLineString *multiLineString
 		int level2=level;
 		bool doIndent=indentFirst;
 		writer->write("(");
-		for (int i=0; i<multiLineString->getNumGeometries();i++) {
+		for (unsigned int i=0, n=multiLineString->getNumGeometries();
+				i<n; i++)
+		{
 			if (i>0) {
 				writer->write(", ");
 				level2=level+1;
@@ -271,7 +370,9 @@ void WKTWriter::appendMultiPolygonText(const MultiPolygon *multiPolygon, int lev
 		int level2=level;
 		bool doIndent=false;
 		writer->write("(");
-		for (int i=0; i<multiPolygon->getNumGeometries();i++) {
+		for (unsigned int i=0, n=multiPolygon->getNumGeometries();
+				i < n; i++)
+		{
 			if (i>0) {
 				writer->write(", ");
 				level2=level+1;
@@ -283,13 +384,20 @@ void WKTWriter::appendMultiPolygonText(const MultiPolygon *multiPolygon, int lev
 	}
 }
 
-void WKTWriter::appendGeometryCollectionText(const GeometryCollection *geometryCollection, int level, Writer *writer) {
+void
+WKTWriter::appendGeometryCollectionText(
+		const GeometryCollection *geometryCollection,
+		int level,
+		Writer *writer)
+{
 	if (geometryCollection->isEmpty()) {
 		writer->write("EMPTY");
 	} else {
 		int level2=level;
 		writer->write("(");
-		for (int i=0; i<geometryCollection->getNumGeometries();i++) {
+		for (unsigned int i=0, n=geometryCollection->getNumGeometries();
+				i < n ; ++i)
+		{
 			if (i>0) {
 				writer->write(", ");
 				level2=level+1;
@@ -307,10 +415,66 @@ void WKTWriter::indent(int level, Writer *writer) {
 	writer->write(string(INDENT * level, ' '));
 }
 
-}
+} // namespace geos.io
+} // namespace geos
 
 /**********************************************************************
- * $Log: WKTWriter.cpp,v $
+ * $Log$
+ * Revision 1.35  2006/06/12 16:55:53  strk
+ * fixed compiler warnings, fixed some methods to omit unused parameters.
+ *
+ * Revision 1.34  2006/06/08 17:58:57  strk
+ * Polygon::getNumInteriorRing() return size_t, Polygon::interiorRingN() takes size_t.
+ *
+ * Revision 1.33  2006/06/01 11:49:36  strk
+ * Reduced installed headers form geomgraph namespace
+ *
+ * Revision 1.32  2006/04/28 11:12:31  strk
+ * removed warnings related to change in getNumPoints() return type.
+ *
+ * Revision 1.31  2006/04/07 09:54:30  strk
+ * Geometry::getNumGeometries() changed to return 'unsigned int'
+ * rather then 'int'
+ *
+ * Revision 1.30  2006/03/22 16:58:35  strk
+ * Removed (almost) all inclusions of geom.h.
+ * Removed obsoleted .cpp files.
+ * Fixed a bug in WKTReader not using the provided CoordinateSequence
+ * implementation, optimized out some memory allocations.
+ *
+ * Revision 1.29  2006/03/20 18:18:15  strk
+ * io.h header split
+ *
+ * Revision 1.28  2006/03/09 16:46:49  strk
+ * geos::geom namespace definition, first pass at headers split
+ *
+ * Revision 1.27  2006/03/06 19:40:47  strk
+ * geos::util namespace. New GeometryCollection::iterator interface, many cleanups.
+ *
+ * Revision 1.26  2006/03/06 15:23:14  strk
+ * geos::io namespace
+ *
+ * Revision 1.25  2006/03/03 10:46:21  strk
+ * Removed 'using namespace' from headers, added missing headers in .cpp files, removed useless includes in headers (bug#46)
+ *
+ * Revision 1.24  2006/02/09 15:52:47  strk
+ * GEOSException derived from std::exception; always thrown and cought by const ref.
+ *
+ * Revision 1.23  2006/02/08 17:18:28  strk
+ * - New WKTWriter::toLineString and ::toPoint convenience methods
+ * - New IsValidOp::setSelfTouchingRingFormingHoleValid method
+ * - New Envelope::centre()
+ * - New Envelope::intersection(Envelope)
+ * - New Envelope::expandBy(distance, [ydistance])
+ * - New LineString::reverse()
+ * - New MultiLineString::reverse()
+ * - New Geometry::buffer(distance, quadSeg, endCapStyle)
+ * - Obsoleted toInternalGeometry/fromInternalGeometry
+ * - More const-correctness in Buffer "package"
+ *
+ * Revision 1.22  2006/01/18 17:46:57  strk
+ * Fixed leak in ::writeFormatted(Geometry *)
+ *
  * Revision 1.21  2004/12/08 13:54:43  strk
  * gcc warnings checked and fixed, general cleanups.
  *
